@@ -105,9 +105,34 @@ def parse_eff(eff, pos):
     pad = 10
     pos = int(pos)
     mut_type = type(eff).__name__
+    d2s = []
+    if eff.transcript is None:
+        distance2splice = None
+    else:
+        for i, exon in enumerate(eff.transcript.exons):
+            if i == 0:
+                if exon.strand == "+":
+                    d2s.append(pos - exon.end)
+                else:
+                    d2s.append(exon.start - pos)
+            elif i == len(eff.transcript.exons) - 1:
+                if exon.strand == "+":
+                    d2s.append(pos - exon.start)
+                else:
+                    d2s.append(exon.end - pos)
+            else:
+                if exon.strand == "+":
+                    d2s.append(pos - exon.start)
+                    d2s.append(pos - exon.end)
+                else:
+                    d2s.append(exon.start - pos)
+                    d2s.append(exon.end - pos)
+        # minus distance to splice site
+        distance2splice = sorted(d2s, key=lambda x: abs(x))[0]
+
     transcript_id = None if mut_type == "Intergenic" else eff.transcript_id
 
-    non_exon_recored = [mut_type, eff.gene_name, transcript_id] + [None] * 6
+    non_exon_recored = [mut_type, eff.gene_name, transcript_id] + [None] * 7
     if mut_type in ["Intergenic", "Intronic", "SpliceDonor"]:
         return non_exon_recored
     try:
@@ -169,6 +194,7 @@ def parse_eff(eff, pos):
         codon_ref,
         aa_pos,
         aa_ref,
+        distance2splice,
     ]
 
 
@@ -236,14 +262,15 @@ def run():
             "codon_ref",
             "aa_pos",
             "aa_ref",
+            "distance2splice",
         ]
         print("#" + "\t".join(input_header + annot_header), file=output_f)
         for l in f:
             c, p, s, ref, alt, *_ = l.strip("\n").split("\t")
             mode = "RNA" if args.rna else "DNA"
             if mode == "RNA" and s == "-":
-                ref = reverse_base(ref)
-                alt = reverse_base(alt)
+                ref = reverse_base(ref.upper())
+                alt = reverse_base(alt.upper())
             annot_list = site2mut(
                 c, p, s, ref, alt, ensembl_genome, mode=mode, all=args.all
             )
